@@ -49,11 +49,11 @@ print.summary_hIRT <- function(x, digits = 3, ...) {
   model_sum <- as.data.frame(x[["model"]], row.names = "")
   print(model_sum)
   cat("\n Item Coefficients: \n")
-  print(x[["item_coefs"]])
+  print(x[["item_coefs"]], ...)
   cat("\n Mean Regression Coefficients:\n")
-  print(x[["mean_coefs"]], print.gap = 2, quote = FALSE)
+  print(x[["mean_coefs"]], ...)
   cat("\n Variance Regression Coefficients:\n")
-  print(x[["var_coefs"]], print.gap = 2, quote = FALSE)
+  print(x[["var_coefs"]], ...)
   cat("\n\n")
   invisible(x)
 }
